@@ -25,28 +25,102 @@ our @EXPORT_OK = qw(
     ouroboros_stack_xpush_uv_ptr
     ouroboros_stack_xpush_nv_ptr
     ouroboros_stack_xpush_pv_ptr
+    ouroboros_stack_xpush_mortal_ptr
     ouroboros_stack_push_sv_ptr
     ouroboros_stack_push_sv_mortal_ptr
     ouroboros_stack_push_iv_ptr
     ouroboros_stack_push_uv_ptr
     ouroboros_stack_push_nv_ptr
     ouroboros_stack_push_pv_ptr
-    ouroboros_sv_iv_ptr
-    ouroboros_sv_uv_ptr
-    ouroboros_sv_nv_ptr
-    ouroboros_sv_pv_ptr
-    ouroboros_sv_pv_nolen_ptr
+    ouroboros_stack_push_mortal_ptr
+    ouroboros_sv_upgrade_ptr
+    ouroboros_sv_niok_ptr
+    ouroboros_sv_niok_priv_ptr
+    ouroboros_sv_niok_off_ptr
+    ouroboros_sv_ok_ptr
+    ouroboros_sv_iok_priv_ptr
+    ouroboros_sv_nok_priv_ptr
+    ouroboros_sv_pok_priv_ptr
+    ouroboros_sv_iok_ptr
+    ouroboros_sv_iok_on_ptr
+    ouroboros_sv_iok_off_ptr
+    ouroboros_sv_iok_only_ptr
+    ouroboros_sv_iok_only_uv_ptr
+    ouroboros_sv_iok_uv_ptr
+    ouroboros_sv_uok_ptr
+    ouroboros_sv_iok_not_uv_ptr
+    ouroboros_sv_nok_ptr
+    ouroboros_sv_nok_on_ptr
+    ouroboros_sv_nok_off_ptr
+    ouroboros_sv_nok_only_ptr
+    ouroboros_sv_pok_ptr
+    ouroboros_sv_pok_on_ptr
+    ouroboros_sv_pok_off_ptr
+    ouroboros_sv_pok_only_ptr
+    ouroboros_sv_pok_only_utf8_ptr
+    ouroboros_sv_vok_ptr
+    ouroboros_sv_ook_ptr
+    ouroboros_sv_ook_offset_ptr
     ouroboros_sv_rok_ptr
+    ouroboros_sv_rok_on_ptr
+    ouroboros_sv_rok_off_ptr
+    ouroboros_sv_iv_ptr
+    ouroboros_sv_iv_nomg_ptr
+    ouroboros_sv_iv_raw_ptr
+    ouroboros_sv_iv_set_ptr
+    ouroboros_sv_uv_ptr
+    ouroboros_sv_uv_nomg_ptr
+    ouroboros_sv_uv_raw_ptr
+    ouroboros_sv_uv_set_ptr
+    ouroboros_sv_nv_ptr
+    ouroboros_sv_nv_nomg_ptr
+    ouroboros_sv_nv_raw_ptr
+    ouroboros_sv_nv_set_ptr
+    ouroboros_sv_pv_ptr
+    ouroboros_sv_pv_nomg_ptr
+    ouroboros_sv_pv_nolen_ptr
+    ouroboros_sv_pv_nomg_nolen_ptr
+    ouroboros_sv_pv_raw_ptr
+    ouroboros_sv_pv_cur_ptr
+    ouroboros_sv_pv_cur_set_ptr
+    ouroboros_sv_pv_len_ptr
+    ouroboros_sv_pv_len_set_ptr
+    ouroboros_sv_pv_end_ptr
     ouroboros_sv_rv_ptr
+    ouroboros_sv_rv_set_ptr
+    ouroboros_sv_true_ptr
+    ouroboros_sv_true_nomg_ptr
     ouroboros_sv_type_ptr
     ouroboros_sv_flags_ptr
     ouroboros_sv_utf8_ptr
     ouroboros_sv_utf8_on_ptr
     ouroboros_sv_utf8_off_ptr
+    ouroboros_sv_is_cow_ptr
+    ouroboros_sv_is_cow_shared_hash_ptr
+    ouroboros_sv_tainted_ptr
+    ouroboros_sv_tainted_on_ptr
+    ouroboros_sv_tainted_off_ptr
+    ouroboros_sv_taint_ptr
+    ouroboros_sv_share_ptr
+    ouroboros_sv_lock_ptr
+    ouroboros_sv_unlock_ptr
+    ouroboros_sv_get_a_magic_ptr
+    ouroboros_sv_magic_set_ptr
+    ouroboros_sv_get_magic_ptr
+    ouroboros_sv_set_magic_ptr
     ouroboros_gv_sv_ptr
     ouroboros_gv_av_ptr
     ouroboros_gv_hv_ptr
     ouroboros_gv_cv_ptr
+    ouroboros_sv_stash_ptr
+    ouroboros_sv_stash_set_ptr
+    ouroboros_cv_stash_ptr
+    ouroboros_hv_name_ptr
+    ouroboros_hv_name_len_ptr
+    ouroboros_hv_name_utf8_ptr
+    ouroboros_hv_ename_ptr
+    ouroboros_hv_ename_len_ptr
+    ouroboros_hv_ename_utf8_ptr
     ouroboros_he_pv_ptr
     ouroboros_he_val_ptr
     ouroboros_he_hash_ptr
@@ -67,6 +141,10 @@ our @EXPORT_OK = qw(
     ouroboros_freetmps_ptr
     ouroboros_sys_init3_ptr
     ouroboros_sys_term_ptr
+    ouroboros_sv_undef_ptr
+    ouroboros_sv_no_ptr
+    ouroboros_sv_yes_ptr
+    ouroboros_gimme_ptr
     ouroboros_xcpt_try_ptr
     ouroboros_xcpt_rethrow_ptr
 );
@@ -80,7 +158,7 @@ our %EXPORT_TAGS = (
 
 our @EXPORT = qw();
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 require XSLoader;
 XSLoader::load('Ouroboros', $VERSION);
@@ -251,6 +329,12 @@ Perl macro: C<mXPUSHn>
 
 Perl macro: C<mXPUSHp>
 
+=item ouroboros_stack_xpush_mortal_ptr
+
+    void ouroboros_stack_xpush_mortal(pTHX_ ouroboros_stack_t*);
+
+Perl macro: C<XPUSHmortal>
+
 =item ouroboros_stack_push_sv_ptr
 
     void ouroboros_stack_push_sv(pTHX_ ouroboros_stack_t*, SV*);
@@ -287,35 +371,179 @@ Perl macro: C<mPUSHn>
 
 Perl macro: C<mPUSHp>
 
-=item ouroboros_sv_iv_ptr
+=item ouroboros_stack_push_mortal_ptr
 
-    IV ouroboros_sv_iv(pTHX_ SV*);
+    void ouroboros_stack_push_mortal(pTHX_ ouroboros_stack_t*);
 
-Perl macro: C<SvIV>
+Perl macro: C<PUSHmortal>
 
-=item ouroboros_sv_uv_ptr
+=item ouroboros_sv_upgrade_ptr
 
-    UV ouroboros_sv_uv(pTHX_ SV*);
+    void ouroboros_sv_upgrade(pTHX_ SV*, svtype);
 
-Perl macro: C<SvUV>
+Perl macro: C<SvUPGRADE>
 
-=item ouroboros_sv_nv_ptr
+=item ouroboros_sv_niok_ptr
 
-    NV ouroboros_sv_nv(pTHX_ SV*);
+    U32 ouroboros_sv_niok(pTHX_ SV*);
 
-Perl macro: C<SvNV>
+Perl macro: C<SvNIOK>
 
-=item ouroboros_sv_pv_ptr
+=item ouroboros_sv_niok_priv_ptr
 
-    const char* ouroboros_sv_pv(pTHX_ SV*, STRLEN*);
+    U32 ouroboros_sv_niok_priv(pTHX_ SV*);
 
-Perl macro: C<SvPV>
+Perl macro: C<SvNIOKp>
 
-=item ouroboros_sv_pv_nolen_ptr
+=item ouroboros_sv_niok_off_ptr
 
-    const char* ouroboros_sv_pv_nolen(pTHX_ SV*);
+    void ouroboros_sv_niok_off(pTHX_ SV*);
 
-Perl macro: C<SvPV_nolen>
+Perl macro: C<SvNIOK_off>
+
+=item ouroboros_sv_ok_ptr
+
+    U32 ouroboros_sv_ok(pTHX_ SV*);
+
+Perl macro: C<SvOK>
+
+=item ouroboros_sv_iok_priv_ptr
+
+    U32 ouroboros_sv_iok_priv(pTHX_ SV*);
+
+Perl macro: C<SvIOKp>
+
+=item ouroboros_sv_nok_priv_ptr
+
+    U32 ouroboros_sv_nok_priv(pTHX_ SV*);
+
+Perl macro: C<SvNOKp>
+
+=item ouroboros_sv_pok_priv_ptr
+
+    U32 ouroboros_sv_pok_priv(pTHX_ SV*);
+
+Perl macro: C<SvPOKp>
+
+=item ouroboros_sv_iok_ptr
+
+    U32 ouroboros_sv_iok(pTHX_ SV*);
+
+Perl macro: C<SvIOK>
+
+=item ouroboros_sv_iok_on_ptr
+
+    void ouroboros_sv_iok_on(pTHX_ SV*);
+
+Perl macro: C<SvIOK_on>
+
+=item ouroboros_sv_iok_off_ptr
+
+    void ouroboros_sv_iok_off(pTHX_ SV*);
+
+Perl macro: C<SvIOK_off>
+
+=item ouroboros_sv_iok_only_ptr
+
+    void ouroboros_sv_iok_only(pTHX_ SV*);
+
+Perl macro: C<SvIOK_only>
+
+=item ouroboros_sv_iok_only_uv_ptr
+
+    void ouroboros_sv_iok_only_uv(pTHX_ SV*);
+
+Perl macro: C<SvIOK_only_UV>
+
+=item ouroboros_sv_iok_uv_ptr
+
+    bool ouroboros_sv_iok_uv(pTHX_ SV*);
+
+Perl macro: C<SvIOK_UV>
+
+=item ouroboros_sv_uok_ptr
+
+    bool ouroboros_sv_uok(pTHX_ SV*);
+
+Perl macro: C<SvUOK>
+
+=item ouroboros_sv_iok_not_uv_ptr
+
+    bool ouroboros_sv_iok_not_uv(pTHX_ SV*);
+
+Perl macro: C<SvIOK_notUV>
+
+=item ouroboros_sv_nok_ptr
+
+    U32 ouroboros_sv_nok(pTHX_ SV*);
+
+Perl macro: C<SvNOK>
+
+=item ouroboros_sv_nok_on_ptr
+
+    void ouroboros_sv_nok_on(pTHX_ SV*);
+
+Perl macro: C<SvNOK_on>
+
+=item ouroboros_sv_nok_off_ptr
+
+    void ouroboros_sv_nok_off(pTHX_ SV*);
+
+Perl macro: C<SvNOK_off>
+
+=item ouroboros_sv_nok_only_ptr
+
+    void ouroboros_sv_nok_only(pTHX_ SV*);
+
+Perl macro: C<SvNOK_only>
+
+=item ouroboros_sv_pok_ptr
+
+    U32 ouroboros_sv_pok(pTHX_ SV*);
+
+Perl macro: C<SvPOK>
+
+=item ouroboros_sv_pok_on_ptr
+
+    void ouroboros_sv_pok_on(pTHX_ SV*);
+
+Perl macro: C<SvPOK_on>
+
+=item ouroboros_sv_pok_off_ptr
+
+    void ouroboros_sv_pok_off(pTHX_ SV*);
+
+Perl macro: C<SvPOK_off>
+
+=item ouroboros_sv_pok_only_ptr
+
+    void ouroboros_sv_pok_only(pTHX_ SV*);
+
+Perl macro: C<SvPOK_only>
+
+=item ouroboros_sv_pok_only_utf8_ptr
+
+    void ouroboros_sv_pok_only_utf8(pTHX_ SV*);
+
+Perl macro: C<SvPOK_only_UTF8>
+
+=item ouroboros_sv_vok_ptr
+
+    bool ouroboros_sv_vok(pTHX_ SV*);
+
+Perl macro: C<SvVOK>
+
+=item ouroboros_sv_ook_ptr
+
+    U32 ouroboros_sv_ook(pTHX_ SV*);
+
+Perl macro: C<SvOOK>
+
+=item ouroboros_sv_ook_offset_ptr
+
+    void ouroboros_sv_ook_offset(pTHX_ SV*, STRLEN*);
+
+Perl macro: C<SvOOK_offset>
 
 =item ouroboros_sv_rok_ptr
 
@@ -323,12 +551,174 @@ Perl macro: C<SvPV_nolen>
 
 Perl macro: C<SvROK>
 
+=item ouroboros_sv_rok_on_ptr
+
+    void ouroboros_sv_rok_on(pTHX_ SV*);
+
+Perl macro: C<SvROK_on>
+
+=item ouroboros_sv_rok_off_ptr
+
+    void ouroboros_sv_rok_off(pTHX_ SV*);
+
+Perl macro: C<SvROK_off>
+
+=item ouroboros_sv_iv_ptr
+
+    IV ouroboros_sv_iv(pTHX_ SV*);
+
+Perl macro: C<SvIV>
+
+=item ouroboros_sv_iv_nomg_ptr
+
+    IV ouroboros_sv_iv_nomg(pTHX_ SV*);
+
+Perl macro: C<SvIV_nomg>
+
+=item ouroboros_sv_iv_raw_ptr
+
+    IV ouroboros_sv_iv_raw(pTHX_ SV*);
+
+Perl macro: C<SvIVX>
+
+=item ouroboros_sv_iv_set_ptr
+
+    void ouroboros_sv_iv_set(pTHX_ SV*, IV);
+
+Perl macro: C<SvIV_set>
+
+=item ouroboros_sv_uv_ptr
+
+    UV ouroboros_sv_uv(pTHX_ SV*);
+
+Perl macro: C<SvUV>
+
+=item ouroboros_sv_uv_nomg_ptr
+
+    UV ouroboros_sv_uv_nomg(pTHX_ SV*);
+
+Perl macro: C<SvUV_nomg>
+
+=item ouroboros_sv_uv_raw_ptr
+
+    UV ouroboros_sv_uv_raw(pTHX_ SV*);
+
+Perl macro: C<SvUVX>
+
+=item ouroboros_sv_uv_set_ptr
+
+    void ouroboros_sv_uv_set(pTHX_ SV*, UV);
+
+Perl macro: C<SvUV_set>
+
+=item ouroboros_sv_nv_ptr
+
+    NV ouroboros_sv_nv(pTHX_ SV*);
+
+Perl macro: C<SvNV>
+
+=item ouroboros_sv_nv_nomg_ptr
+
+    NV ouroboros_sv_nv_nomg(pTHX_ SV*);
+
+Perl macro: C<SvNV_nomg>
+
+=item ouroboros_sv_nv_raw_ptr
+
+    NV ouroboros_sv_nv_raw(pTHX_ SV*);
+
+Perl macro: C<SvNVX>
+
+=item ouroboros_sv_nv_set_ptr
+
+    void ouroboros_sv_nv_set(pTHX_ SV*, NV);
+
+Perl macro: C<SvNV_set>
+
+=item ouroboros_sv_pv_ptr
+
+    const char* ouroboros_sv_pv(pTHX_ SV*, STRLEN*);
+
+Perl macro: C<SvPV>
+
+=item ouroboros_sv_pv_nomg_ptr
+
+    const char* ouroboros_sv_pv_nomg(pTHX_ SV*, STRLEN*);
+
+Perl macro: C<SvPV_nomg>
+
+=item ouroboros_sv_pv_nolen_ptr
+
+    const char* ouroboros_sv_pv_nolen(pTHX_ SV*);
+
+Perl macro: C<SvPV_nolen>
+
+=item ouroboros_sv_pv_nomg_nolen_ptr
+
+    const char* ouroboros_sv_pv_nomg_nolen(pTHX_ SV*);
+
+Perl macro: C<SvPV_nomg_nolen>
+
+=item ouroboros_sv_pv_raw_ptr
+
+    char* ouroboros_sv_pv_raw(pTHX_ SV*);
+
+Perl macro: C<SvPVX>
+
+=item ouroboros_sv_pv_cur_ptr
+
+    STRLEN ouroboros_sv_pv_cur(pTHX_ SV*);
+
+Perl macro: C<SvCUR>
+
+=item ouroboros_sv_pv_cur_set_ptr
+
+    void ouroboros_sv_pv_cur_set(pTHX_ SV*, STRLEN);
+
+Perl macro: C<SvCUR_set>
+
+=item ouroboros_sv_pv_len_ptr
+
+    STRLEN ouroboros_sv_pv_len(pTHX_ SV*);
+
+Perl macro: C<SvLEN>
+
+=item ouroboros_sv_pv_len_set_ptr
+
+    void ouroboros_sv_pv_len_set(pTHX_ SV*, STRLEN);
+
+Perl macro: C<SvLEN_set>
+
+=item ouroboros_sv_pv_end_ptr
+
+    char* ouroboros_sv_pv_end(pTHX_ SV*);
+
+Perl macro: C<SvEND>
+
 =item ouroboros_sv_rv_ptr
 
     SV* ouroboros_sv_rv(pTHX_ SV*);
 
 Perl macro: C<SvRV>
 
+=item ouroboros_sv_rv_set_ptr
+
+    void ouroboros_sv_rv_set(pTHX_ SV*, SV*);
+
+Perl macro: C<SvRV_set>
+
+=item ouroboros_sv_true_ptr
+
+    bool ouroboros_sv_true(pTHX_ SV*);
+
+Perl macro: C<SvTRUE>
+
+=item ouroboros_sv_true_nomg_ptr
+
+    bool ouroboros_sv_true_nomg(pTHX_ SV*);
+
+Perl macro: C<SvTRUE_nomg>
+
 =item ouroboros_sv_type_ptr
 
     IV ouroboros_sv_type(pTHX_ SV*);
@@ -359,6 +749,84 @@ Perl macro: C<SvUTF8_on>
 
 Perl macro: C<SvUTF8_off>
 
+=item ouroboros_sv_is_cow_ptr
+
+    U32 ouroboros_sv_is_cow(pTHX_ SV*);
+
+Perl macro: C<SvIsCOW>
+
+=item ouroboros_sv_is_cow_shared_hash_ptr
+
+    bool ouroboros_sv_is_cow_shared_hash(pTHX_ SV*);
+
+Perl macro: C<SvIsCOW_shared_hash>
+
+=item ouroboros_sv_tainted_ptr
+
+    bool ouroboros_sv_tainted(pTHX_ SV*);
+
+Perl macro: C<SvTAINTED>
+
+=item ouroboros_sv_tainted_on_ptr
+
+    void ouroboros_sv_tainted_on(pTHX_ SV*);
+
+Perl macro: C<SvTAINTED_on>
+
+=item ouroboros_sv_tainted_off_ptr
+
+    void ouroboros_sv_tainted_off(pTHX_ SV*);
+
+Perl macro: C<SvTAINTED_off>
+
+=item ouroboros_sv_taint_ptr
+
+    void ouroboros_sv_taint(pTHX_ SV*);
+
+Perl macro: C<SvTAINT>
+
+=item ouroboros_sv_share_ptr
+
+    void ouroboros_sv_share(pTHX_ SV*);
+
+Perl macro: C<SvSHARE>
+
+=item ouroboros_sv_lock_ptr
+
+    void ouroboros_sv_lock(pTHX_ SV*);
+
+Perl macro: C<SvLOCK>
+
+=item ouroboros_sv_unlock_ptr
+
+    void ouroboros_sv_unlock(pTHX_ SV*);
+
+Perl macro: C<SvUNLOCK>
+
+=item ouroboros_sv_get_a_magic_ptr
+
+    U32 ouroboros_sv_get_a_magic(pTHX_ SV*);
+
+Perl macro: C<SvGAMAGIC>
+
+=item ouroboros_sv_magic_set_ptr
+
+    void ouroboros_sv_magic_set(pTHX_ SV*, MAGIC*);
+
+Perl macro: C<SvMAGIC_set>
+
+=item ouroboros_sv_get_magic_ptr
+
+    void ouroboros_sv_get_magic(pTHX_ SV*);
+
+Perl macro: C<SvGETMAGIC>
+
+=item ouroboros_sv_set_magic_ptr
+
+    void ouroboros_sv_set_magic(pTHX_ SV*);
+
+Perl macro: C<SvSETMAGIC>
+
 =item ouroboros_gv_sv_ptr
 
     SV* ouroboros_gv_sv(pTHX_ GV*);
@@ -383,6 +851,60 @@ Perl macro: C<GvHV>
 
 Perl macro: C<GvCV>
 
+=item ouroboros_sv_stash_ptr
+
+    HV* ouroboros_sv_stash(pTHX_ SV*);
+
+Perl macro: C<SvSTASH>
+
+=item ouroboros_sv_stash_set_ptr
+
+    void ouroboros_sv_stash_set(pTHX_ SV*, HV*);
+
+Perl macro: C<SvSTASH_set>
+
+=item ouroboros_cv_stash_ptr
+
+    void ouroboros_cv_stash(pTHX_ CV*);
+
+Perl macro: C<CvSTASH>
+
+=item ouroboros_hv_name_ptr
+
+    const char* ouroboros_hv_name(pTHX_ HV*);
+
+Perl macro: C<HvNAME>
+
+=item ouroboros_hv_name_len_ptr
+
+    STRLEN ouroboros_hv_name_len(pTHX_ HV*);
+
+Perl macro: C<HvNAMELEN>
+
+=item ouroboros_hv_name_utf8_ptr
+
+    unsigned char ouroboros_hv_name_utf8(pTHX_ HV*);
+
+Perl macro: C<HvNAMEUTF8>
+
+=item ouroboros_hv_ename_ptr
+
+    const char* ouroboros_hv_ename(pTHX_ HV*);
+
+Perl macro: C<HvENAME>
+
+=item ouroboros_hv_ename_len_ptr
+
+    STRLEN ouroboros_hv_ename_len(pTHX_ HV*);
+
+Perl macro: C<HvENAMELEN>
+
+=item ouroboros_hv_ename_utf8_ptr
+
+    unsigned char ouroboros_hv_ename_utf8(pTHX_ HV*);
+
+Perl macro: C<HvENAMEUTF8>
+
 =item ouroboros_he_pv_ptr
 
     const char* ouroboros_he_pv(pTHX_ HE*, STRLEN*);
@@ -505,6 +1027,30 @@ Perl macro: C<PERL_SYS_INIT3>
 
 Perl macro: C<PERL_SYS_TERM>
 
+=item ouroboros_sv_undef_ptr
+
+    SV* ouroboros_sv_undef(pTHX);
+
+Return address of C<PL_sv_undef> global.
+
+=item ouroboros_sv_no_ptr
+
+    SV* ouroboros_sv_no(pTHX);
+
+Return address of C<PL_sv_no> global.
+
+=item ouroboros_sv_yes_ptr
+
+    SV* ouroboros_sv_yes(pTHX);
+
+Return address of C<PL_sv_yes> global.
+
+=item ouroboros_gimme_ptr
+
+    U32 ouroboros_gimme(pTHX);
+
+Perl macro: C<GIMME_V>
+
 =item ouroboros_xcpt_try_ptr
 
     int ouroboros_xcpt_try(pTHX_ ouroboros_xcpt_callback_t, void*);
